<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Traits\TQuery;

class FmRelatoriosOperacionalContratoFactory
{

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    /* Início TAB relatórios tarefas */
    public function getRelatoriosTarefas($parametros, $operadores)
    {
        $session = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI'";

        $this->connection->executeStatement($session);
    
        $sql = "SELECT CHKA.NRCHECKLISTAGEND, CHKA.NRLOCALCLIENTE, CHKA.NRCHECKLIST, CHKA.CDOPERADOR, CHKA.IDSITUACAOAGEND, 
                    CHKA.DTHORAAGEND, CHKA.IDATIVO, CHKA.DTHRFINALAGEND, CHKA.NMCHECKLISTAGEND, CONSULOBS.DSOBSTAREFAAGEND,
                    FUNC.NMOPERADOR, LC.NMLOCALCLIENTE, CHK.NMCHECKLIST, C.NMRAZSOCCLIE, ROUND(24 *(60 *(CHKA.DTHRFINALAGEND - CHKA.DTHORAAGEND)), 2) AS DURACAO, CHKA.DSJUSTCANCELAMENTO,
                    LC.CDCLIENTE, CHKA.NRPRIORIDADETAREFA, CONT.NRCONTRATOFCT, CHKA.NRSEQCONTRATO
                        FROM FCM_CHECKLISTAGEND CHKA
                    LEFT JOIN OPERADOR FUNC 
                        ON FUNC.CDOPERADOR = CHKA.CDOPERADOR
                    LEFT JOIN FCM_LOCALCLI LC
                        ON LC.NRLOCALCLIENTE = CHKA.NRLOCALCLIENTE
                    LEFT JOIN FCM_CHECKLIST CHK
                        ON CHK.NRCHECKLIST = CHKA.NRCHECKLIST
                    LEFT JOIN CLIENTE C
                        ON C.CDCLIENTE = LC.CDCLIENTE
                    LEFT JOIN FCT_CONTRATO CONT
                        ON CONT.NRSEQCONTRATO = CHKA.NRSEQCONTRATO
                    LEFT JOIN (SELECT DISTINCT DSOBSTAREFAAGEND, NRCHECKLISTAGEND
                                    FROM FCM_TAREFAAGEND) CONSULOBS
                        ON CONSULOBS.NRCHECKLISTAGEND = CHKA.NRCHECKLISTAGEND
                      WHERE ((CHKA.CDOPERADOR IN ($operadores))
                         OR (CHKA.CDOPERINCLUSAO = :CDOPERADOR))";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getItensTarefas($parametros)
    {
        $nrchecklistagend = $parametros;

        $sql = "SELECT TA.NRTAREFAAGEND, TA.NRCHECKLISTAGEND, TA.CDOPERADOR, TA.DSOBSTAREFAAGEND, TA.IDREALIZADO, CA.NMCHECKLISTAGEND, TF.NMTAREFA
                    FROM FCM_TAREFAAGEND TA
                    JOIN FCM_CHECKLISTAGEND CA
                      ON CA.NRCHECKLISTAGEND = TA.NRCHECKLISTAGEND
                    JOIN FCM_TAREFACHK T
                      ON T.NRTAREFACHK = TA.NRTAREFACHK
                    JOIN FCM_TAREFA TF
                      ON T.NRTAREFA = TF.NRTAREFA
                   WHERE TA.NRCHECKLISTAGEND = $nrchecklistagend";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFotosTarefas($parametros)
    {
        $nrchecklistagend = $parametros;

        $sql = "SELECT FTA.NRFOTOTAREFAAGEND, FTA.NRTAREFAAGEND, FTA.DSFOTOTAREFAAGEND
                    FROM FCM_FOTOTAREFAAGEND FTA
                    JOIN FCM_TAREFAAGEND TA
                      ON TA.NRTAREFAAGEND = FTA.NRTAREFAAGEND
                    JOIN FCM_CHECKLISTAGEND CHKA
                      ON CHKA.NRCHECKLISTAGEND = TA.NRCHECKLISTAGEND
                   WHERE CHKA.NRCHECKLISTAGEND = $nrchecklistagend";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFiltroRelatorioLocal($listaLocais)
    {
        $sql = "SELECT NRLOCALCLIENTE, NMLOCALCLIENTE
                FROM FCM_LOCALCLI 
                WHERE NRTIPOLOCALCLI IN (SELECT NRTIPOLOCALCLI
                                            FROM FCM_TIPOLOCALCLI
                                        WHERE IDTIPOLOCALCLI = '3') 
                AND IDATIVO = 'S'
                AND NRLOCALCLIENTE IN ($listaLocais)";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFiltroRelatorioCliente()
    {
        $sql = "SELECT CDCLIENTE, NMRAZSOCCLIE 
                FROM CLIENTE
                WHERE IDCLIEATIV = 'S'
                    AND IDATIVO = 'S' 
                    AND CDCLIENTE IN (SELECT CDCLIENTE 
                                        FROM FCM_LOCALCLI
                                    WHERE IDATIVO = 'S')";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
    /* Fim TAB relatórios tarefas */

    /* Estrutura da Hierarquia do Facilities */
    public function getLocaisHierarquia($cdOperador, $entityManager = null)
    {
        $sql = "SELECT FCM_LOCALCLI.NRLOCALCLIENTE
                    FROM FCM_LOCALCLI
                    WHERE FCM_LOCALCLI.NRLOCALCLIENTE IN (SELECT NRLOCALCLIENTE
                                                        FROM FCM_LOCALCLI LOC
                                                        START WITH NRLOCALCLIENTE IN (SELECT FCM_HIERARQUIAFUNC.NRLOCALCLIENTE
                                                                                        FROM FCM_HIERARQUIAFUNC
                                                                                        JOIN FCM_FUNCIONARIOSHIERARQ
                                                                                        ON FCM_FUNCIONARIOSHIERARQ.NRHIERARQUIAFUNC = FCM_HIERARQUIAFUNC.NRHIERARQUIAFUNC
                                                                                        WHERE FCM_FUNCIONARIOSHIERARQ.CDOPERADOR = :CDOPERADOR)
                                                        CONNECT BY PRIOR NRLOCALCLIENTE = NRLOCALCLIENTEPAI)";

        if (empty($entityManager)) {
            return $this->connection->executeQuery($sql, $cdOperador)->fetchAllAssociative();
        } else {
            return $entityManager->getConnection()->executeQuery($sql, $cdOperador)->fetchAllAssociative();
        }
    }

    public function getHierarquiaFacilities($parametros, $locais)
    {
        $sql = "SELECT DISTINCT A.CDOPERADOR
                    FROM FCM_FUNCIONARIOSHIERARQ A
                    JOIN OPERADOR B ON B.CDOPERADOR = A.CDOPERADOR
                    JOIN FCM_HIERARQUIAFUNC H ON H.NRHIERARQUIAFUNC = A.NRHIERARQUIAFUNC
                    WHERE A.NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC
                                                FROM FCM_HIERARQUIAFUNC
                                                WHERE NRLOCALCLIENTE IN ($locais))
                    AND A.CDOPERADOR IN (SELECT CDOPERADOR
                                                    FROM FCM_FUNCIONARIOSHIERARQ F
                                                    JOIN FCM_HIERARQUIAFUNC H
                                                    ON F.NRHIERARQUIAFUNC = H.NRHIERARQUIAFUNC
                                                    AND H.NRLOCALCLIENTE IN ($locais)
                                                    START WITH CDOPERADOR     = :CDOPERADOR
                                                    CONNECT BY PRIOR CDOPERADOR = CDOPERADORPAI)";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function findOperadorHierarq($filtro, $listaLocais)
    {
        $sql = "SELECT DISTINCT OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR, FCM_RELACHABOPER.NRHABILIDADE
                    FROM OPERADOR
                    JOIN FCM_FUNCIONARIOSHIERARQ
                    ON FCM_FUNCIONARIOSHIERARQ.CDOPERADOR = OPERADOR.CDOPERADOR
                    JOIN FCM_HIERARQUIAFUNC
                    ON FCM_HIERARQUIAFUNC.NRHIERARQUIAFUNC = FCM_FUNCIONARIOSHIERARQ.NRHIERARQUIAFUNC
                    LEFT JOIN FCM_RELACHABOPER
                    ON FCM_RELACHABOPER.CDOPERADOR = OPERADOR.CDOPERADOR
                    WHERE FCM_HIERARQUIAFUNC.NRLOCALCLIENTE IN (SELECT NRLOCALCLIENTE
                                            FROM FCM_LOCALCLI
                                            START WITH NRLOCALCLIENTE IN ($listaLocais)
                                            CONNECT BY PRIOR NRLOCALCLIENTEPAI = NRLOCALCLIENTE) 
                    AND " . $filtro . "
                    ORDER BY OPERADOR.NMOPERADOR";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }


    /* Inicio TAB relatórios Vistorias */

    public function getRelatoriosVistoria($operadores, $params)
    {

        $session = "ALTER SESSION SET NLS_DATE_FORMAT = 'DD/MM/YYYY HH24:MI'";
        $this->connection->executeStatement($session);

        $sql = "SELECT GCHK.NRGERENCIAMENTOCHK, GCHK.NRLOCALCLIENTE, GCHK.NRCHECKLIST, GCHK.CDOPERADOR, GCHK.IDATIVO, GCHK.NMGERENCIAMENTOCHK, 
                        GCHK.DTHORAAGEND, GCHK.DTHRFINALAGEND, GCHK.NRCHECKLISTAGEND, F.NMOPERADOR, LC.NMLOCALCLIENTE, LC.CDCLIENTE, CHK.NMCHECKLIST, C.NMRAZSOCCLIE, 
                        ROUND(24 *(60 *(GCHK.DTHRFINALAGEND - GCHK.DTHORAAGEND)), 2) || ' min' AS DURACAO,  CHKA.IDSITUACAOAGEND, CONT.NRCONTRATOFCT, GCHK.NRSEQCONTRATO,
                        DECODE(CHKA.IDSITUACAOAGEND,
                            '1', CASE GCHK.IDSITUACAOGERCHK
                                WHEN '4' THEN 'Em andamento (Tarefa em correção)'
                                ELSE 'Tarefa Pendente' END,
                            '4', CASE GCHK.IDSITUACAOGERCHK 
                                WHEN '1' THEN 'Aguardando Vistoria'
                                WHEN '2' THEN 'Em andamento'
                                WHEN '3' THEN 'Avaliado'
                                WHEN '5' THEN 'Cancelado'
                                ELSE NULL END,
                            NULL, CASE GCHK.IDSITUACAOGERCHK 
                                WHEN '1' THEN 'Aguardando Vistoria'
                                WHEN '2' THEN 'Em andamento'
                                WHEN '3' THEN 'Avaliado'
                                ELSE NULL END,
                            'Tarefa Pendente'
                        ) AS IDSITUACAOGERCHK          
                            FROM FCM_GERENCIAMENTOCHK GCHK
                        LEFT JOIN OPERADOR F
                            ON F.CDOPERADOR = GCHK.CDOPERADOR
                        LEFT JOIN FCM_LOCALCLI LC
                            ON LC.NRLOCALCLIENTE = GCHK.NRLOCALCLIENTE
                        LEFT JOIN FCM_CHECKLIST CHK
                            ON CHK.NRCHECKLIST = GCHK.NRCHECKLIST
                        LEFT JOIN CLIENTE C
                            ON C.CDCLIENTE = LC.CDCLIENTE
                        LEFT JOIN FCM_CHECKLISTAGEND CHKA
                            ON CHKA.NRCHECKLISTAGEND = GCHK.NRCHECKLISTAGEND
                        LEFT JOIN FCT_CONTRATO CONT
                            ON CONT.NRSEQCONTRATO = CHKA.NRSEQCONTRATO
                            WHERE ((CHKA.CDOPERADOR IN ($operadores))
                            OR (CHKA.CDOPERINCLUSAO = :CDOPERADOR))";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function getFiltroVistoriaSituacao()
    {
        $sql = "SELECT DISTINCT DECODE(CHKA.IDSITUACAOAGEND,
                            '1', CASE GCHK.IDSITUACAOGERCHK
                                WHEN '4' THEN 'Em andamento (Tarefa em correção)'
                                ELSE 'Tarefa Pendente' END,
                            '4', CASE GCHK.IDSITUACAOGERCHK 
                                WHEN '1' THEN 'Aguardando Vistoria'
                                WHEN '2' THEN 'Em andamento'
                                WHEN '3' THEN 'Avaliado'
                                WHEN '5' THEN 'Cancelado'
                                ELSE NULL END,
                            NULL, CASE GCHK.IDSITUACAOGERCHK 
                                WHEN '1' THEN 'Aguardando Vistoria'
                                WHEN '2' THEN 'Em andamento'
                                WHEN '3' THEN 'Avaliado'
                                ELSE NULL END,
                            'Tarefa Pendente'
                        ) AS IDSITUACAOGERCHK,
                        DECODE(CHKA.IDSITUACAOAGEND, '4', CASE GCHK.IDSITUACAOGERCHK 
                                        WHEN '1' THEN '1'
                                        WHEN '2' THEN '2'
                                        WHEN '3' THEN '3'
                                        WHEN '4' THEN '4'
                                        WHEN '4' THEN '5'
                                        ELSE NULL END, '0') AS IDSITUACAOGERCHK
                    FROM FCM_GERENCIAMENTOCHK GCHK
                    LEFT JOIN FCM_CHECKLISTAGEND CHKA
                    ON CHKA.NRCHECKLISTAGEND = GCHK.NRCHECKLISTAGEND";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getCriteriosVistoria($parametros)
    {
        $nrgerenciamentochk = $parametros;

        $sql = "SELECT CG.NRCRITERIOTARGERCHK, CG.IDMARCADO, TG.DSOBSTAREFAGERCHK,A.NMATIVIDADE || ' - ' || CG.NMCRITERIOTARGERCHK  AS NMCRITERIO
                        FROM FCM_CRITERIOTARGERCHK CG
                        JOIN FCM_TAREFAGERCHK TG
                        ON TG.NRTAREFAGERCHK = CG.NRTAREFAGERCHK
                        JOIN FCM_TAREFACHK TCHK
                        ON TCHK.NRTAREFACHK = TG.NRTAREFACHK
                        JOIN FCM_ATIVIDADECHK ACHK
                        ON ACHK.NRATIVIDADECHK = TCHK.NRATIVIDADECHK
                        JOIN FCM_ATIVIDADE A
                        ON A.NRATIVIDADE = ACHK.NRATIVIDADE
                    WHERE TG.NRGERENCIAMENTOCHK = $nrgerenciamentochk";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getFotosVistoria($parametros)
    {
        $nrgerenciamentochk = $parametros;

        $sql = "SELECT FGCHK.NRFOTOTAREFAGERCHK, FGCHK.NRTAREFAGERCHK, FGCHK.DSFOTOTAREFAGERCHK
                    FROM FCM_FOTOTAREFAGERCHK FGCHK
                    JOIN FCM_TAREFAGERCHK TGCHK
                      ON TGCHK.NRTAREFAGERCHK = FGCHK.NRTAREFAGERCHK
                    JOIN FCM_GERENCIAMENTOCHK GCHK
                      ON TGCHK.NRGERENCIAMENTOCHK = GCHK.NRGERENCIAMENTOCHK
                   WHERE GCHK.NRGERENCIAMENTOCHK = $nrgerenciamentochk";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
    /* Fim TAB relatórios Vistorias */

    /* Inicio TAB relatórios auditorias */

    public function getTarefasAuditoria($listaOperadores, $params)
    {
        $sql = "SELECT 
                    FCM_AUDITORIA.NRAUDITORIA, 
                    FCM_AUDITORIA.NMAUDITORIA, 
                    FCM_AUDITORIA.NRLOCALCLIENTE, 
                    FCM_AUDITORIA.IDTIPOMARCACAO, 
                    FCM_LOCALCLI.NMLOCALCLIENTE, 
                    FCM_LOCALCLI.CDCLIENTE, 
                    FCM_LOCALCLI.NRTIPOLOCALCLI, 
                    FCM_MODELOAUDIT.NRMODELOAUDIT, 
                    FCM_MODELOAUDIT.NMMODELOAUDIT, 
                    FCM_AUDITORIA.NRSEQCONTRATO, 
                    FCT_CONTRATO.NRCONTRATOFCT, 
                    FCM_AUDITORIA.CDOPERADOR, 
                    OPERADOR.NMOPERADOR, 
                    FCM_AUDITORIA.IDSITUACAOAUDIT, 
                    TO_CHAR(FCM_AUDITORIA.DTHORAAUDIT, 'DD/MM/YYYY') AS DTHORAAUDIT, 
                    FCM_AUDITORIA.IDTIPORECORRENCIA, 
                    FCM_TIPOLOCALCLI.NMTIPOLOCALCLI, 
                    CLIENTE.NMRAZSOCCLIE, 
                    CLIENTE.NMFANTCLIE, 
                    FCM_AUDITORIA.IDATIVO,
                    FCM_AUDITORIA.NOTATOTAL,      
                    FCM_AUDITORIA.PERCENTUALCONCLUSAO  
                FROM 
                    FCM_AUDITORIA
                LEFT JOIN 
                    FCM_LOCALCLI ON FCM_LOCALCLI.NRLOCALCLIENTE = FCM_AUDITORIA.NRLOCALCLIENTE
                JOIN 
                    CLIENTE ON CLIENTE.CDCLIENTE = FCM_LOCALCLI.CDCLIENTE
                JOIN 
                    FCM_TIPOLOCALCLI ON FCM_LOCALCLI.NRTIPOLOCALCLI = FCM_TIPOLOCALCLI.NRTIPOLOCALCLI
                LEFT JOIN 
                    FCM_MODELOAUDIT ON FCM_MODELOAUDIT.NRMODELOAUDIT = FCM_AUDITORIA.NRMODELOAUDIT
                LEFT JOIN 
                    FCT_CONTRATO ON FCT_CONTRATO.NRSEQCONTRATO = FCM_AUDITORIA.NRSEQCONTRATO
                LEFT JOIN 
                    OPERADOR ON OPERADOR.CDOPERADOR = FCM_AUDITORIA.CDOPERADOR
                WHERE  (FCM_AUDITORIA.CDOPERADOR IN ($listaOperadores) OR FCM_AUDITORIA.CDOPERINCLUSAO = :CDOPERADOR)";

        // Executa a consulta e retorna os resultados
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function getCategoriasAuditoriaRelatorio($parametros)
    {
        $sql = "SELECT FCM_RELACMODCATEG.*, FCM_CATEGORIAAUDIT.NMCATEGORIAAUDIT 
                FROM FCM_RELACMODCATEG
                JOIN FCM_AUDITORIA
                ON FCM_AUDITORIA.NRMODELOAUDIT = FCM_RELACMODCATEG.NRMODELOAUDIT
                JOIN FCM_CATEGORIAAUDIT
                ON FCM_CATEGORIAAUDIT.NRCATEGORIAAUDIT = FCM_RELACMODCATEG.NRCATEGORIAAUDIT
                WHERE FCM_AUDITORIA.NRAUDITORIA = :NRAUDITORIA";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getParametrizacao() 
    {
        $sql = "SELECT IDUTILIZAPERCENTUALAUDIT, IDUTILIZANOTAAUDIT
                FROM FCM_PARAMGERAL";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getCriteriosAvaliacaoSomaPercentual()
    {
        $sql = "SELECT NRCRITERIOAUDIT FROM FCM_CRITERIOAUDIT
                WHERE IDSOMAPERCENTUAL = 'S'";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getTopicosAuditoriaExecRelatorio($parametros)
    {
        $sql = "SELECT
                FCM_RELACCATTOPIC.*,
                FCM_TOPICOAUDIT.NMTOPICOAUDIT,
                FCM_OBSRESULTAUDIT.DSOBSERVACAO,
                FCM_OBSRESULTAUDIT.NROBSRESULTAUDIT
                FROM
                    FCM_RELACCATTOPIC
                JOIN FCM_AUDITORIA ON FCM_AUDITORIA.NRMODELOAUDIT = FCM_RELACCATTOPIC.NRMODELOAUDIT
                JOIN FCM_TOPICOAUDIT ON FCM_TOPICOAUDIT.NRTOPICOAUDIT = FCM_RELACCATTOPIC.NRTOPICOAUDIT
                LEFT JOIN FCM_OBSRESULTAUDIT ON FCM_OBSRESULTAUDIT.NRRELACCATTOPIC = FCM_RELACCATTOPIC.NRRELACCATTOPIC AND FCM_OBSRESULTAUDIT.NRAUDITORIA = FCM_AUDITORIA.NRAUDITORIA
                WHERE
                FCM_AUDITORIA.NRAUDITORIA = :NRAUDITORIA
                AND FCM_RELACCATTOPIC.NRCATEGORIAAUDIT = :NRCATEGORIAAUDIT";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getCriteriosAudit($parametros) 
    {
        $sql = "SELECT FCM_RELACRESULTCRIT.NRCRITERIOAUDIT, 
                       FCM_RELACRESULTCRIT.NRRESULTADOAUDIT,
                       FCM_RELACRESULTCRIT.IDREALIZADO
                FROM FCM_RELACRESULTCRIT
                JOIN FCM_RESULTADOAUDIT
                ON FCM_RESULTADOAUDIT.NRRESULTADOAUDIT = FCM_RELACRESULTCRIT.NRRESULTADOAUDIT
                JOIN FCM_CRITERIOAUDIT
                ON FCM_CRITERIOAUDIT.NRCRITERIOAUDIT = FCM_RELACRESULTCRIT.NRCRITERIOAUDIT
                JOIN FCM_AUDITORIA
                ON FCM_RESULTADOAUDIT.NRAUDITORIA = FCM_AUDITORIA.NRAUDITORIA
                WHERE FCM_RESULTADOAUDIT.NRCATEGORIAAUDIT = (
                    SELECT MAX(NRCATEGORIAAUDIT) FROM FCM_RESULTADOAUDIT 
                    WHERE NRTOPICOAUDIT = :NRTOPICOAUDIT
                )
                AND FCM_RELACRESULTCRIT.NRTOPICOAUDIT = :NRTOPICOAUDIT
                AND FCM_RESULTADOAUDIT.NRAUDITORIA = :NRAUDITORIA";
    
        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getCriteriosAvaliacaoSomaNota()
    {
        $sql = "SELECT NRCRITERIOAUDIT FROM FCM_CRITERIOAUDIT
                WHERE IDSOMANOTA = 'S'";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }

    public function getCriteriosMarcadosAudit($parametros) 
    {
        $sql = "SELECT FCM_RELACRESULTCRIT.NRCRITERIOAUDIT, 
                       FCM_RELACRESULTCRIT.NRRESULTADOAUDIT
                FROM FCM_RELACRESULTCRIT
                JOIN FCM_RESULTADOAUDIT
                ON FCM_RESULTADOAUDIT.NRRESULTADOAUDIT = FCM_RELACRESULTCRIT.NRRESULTADOAUDIT
                JOIN FCM_CRITERIOAUDIT
                ON FCM_CRITERIOAUDIT.NRCRITERIOAUDIT = FCM_RELACRESULTCRIT.NRCRITERIOAUDIT
                JOIN FCM_AUDITORIA
                ON FCM_RESULTADOAUDIT.NRAUDITORIA = FCM_AUDITORIA.NRAUDITORIA
                WHERE FCM_RESULTADOAUDIT.NRCATEGORIAAUDIT = :NRCATEGORIAAUDIT
                AND FCM_RELACRESULTCRIT.NRTOPICOAUDIT = :NRTOPICOAUDIT
                AND FCM_RESULTADOAUDIT.NRAUDITORIA = :NRAUDITORIA
                AND FCM_RELACRESULTCRIT.IDREALIZADO = 'S'";
    
        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getNotaTopico($parametros)
    {
        $sql = "SELECT NOTATOPICAUDIT FROM FCM_TOPICOAUDIT
                WHERE NRTOPICOAUDIT = :NRTOPICOAUDIT";

        return $this->connection->executeQuery($sql, $parametros)->fetchAllAssociative();
    }

    public function getCriteriosAuditoriaExecRelatorio($parametros)
    {
        $sql = "SELECT FCM_RELACRESULTCRIT.NRRELACRESULTCRIT, FCM_RELACRESULTCRIT.NRRESULTADOAUDIT, FCM_RELACRESULTCRIT.NRCRITERIOAUDIT, 
                    FCM_RELACRESULTCRIT.IDREALIZADO, FCM_RELACRESULTCRIT.NRTOPICOAUDIT, FCM_CRITERIOAUDIT.NMCRITERIOAUDIT, FCM_RESULTADOAUDIT.NRCATEGORIAAUDIT
                        FROM FCM_RELACRESULTCRIT
                        JOIN FCM_RESULTADOAUDIT
                        ON FCM_RESULTADOAUDIT.NRRESULTADOAUDIT = FCM_RELACRESULTCRIT.NRRESULTADOAUDIT
                        JOIN FCM_CRITERIOAUDIT
                        ON FCM_CRITERIOAUDIT.NRCRITERIOAUDIT = FCM_RELACRESULTCRIT.NRCRITERIOAUDIT
                        JOIN FCM_AUDITORIA
                        ON FCM_RESULTADOAUDIT.NRAUDITORIA = FCM_AUDITORIA.NRAUDITORIA
                        WHERE FCM_RESULTADOAUDIT.NRCATEGORIAAUDIT = :NRCATEGORIAAUDIT
                        AND FCM_RELACRESULTCRIT.NRTOPICOAUDIT = :NRTOPICOAUDIT
                        AND FCM_RESULTADOAUDIT.NRAUDITORIA = :NRAUDITORIA";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function getImagensTopicosAuditoria($parametros)
    {
        $sql = "SELECT * FROM FCM_FOTORESULTAUDIT
                    WHERE NRAUDITORIA = :NRAUDITORIA
                    AND NRCATEGORIAAUDIT = :NRCATEGORIAAUDIT
                    AND NRTOPICOAUDIT = :NRTOPICOAUDIT";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }
    /* Fim TAB relatórios auditorias */
}